@@ -1,6 +1,6 @@
 ;;; canna.scm: Canna for uim.
 ;;;
-;;; Copyright (c) 2003-2008 uim Project http://code.google.com/p/uim/
+;;; Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 ;;;
 ;;; All rights reserved.
 ;;;
@@ -31,13 +31,12 @@
 
 (require "ustr.scm")
 (require "japanese.scm")
-(require "japanese-kana.scm")
-(require "japanese-azik.scm")
+(require "generic-predict.scm")
+(require "cannav3-socket.scm")
 (require-custom "generic-key-custom.scm")
 (require-custom "canna-custom.scm")
 (require-custom "canna-key-custom.scm")
 
-
 ;;; implementations
 
 (define canna-init-lib-ok? #f)
@@ -52,6 +51,8 @@
 (define canna-input-rule-roma 0)
 (define canna-input-rule-kana 1)
 (define canna-input-rule-azik 2)
+(define canna-input-rule-act 3)
+(define canna-input-rule-kzik 4)
 
 (define canna-candidate-type-katakana -2)
 (define canna-candidate-type-hiragana -3)
@@ -225,6 +226,7 @@
 		      canna-input-rule-kana))
 		 (lambda (cc)
 		   (canna-prepare-input-rule-activation cc)
+                   (require "japanese-kana.scm")
 		   (canna-context-set-input-rule! cc canna-input-rule-kana)
                    (canna-context-change-kana-mode!
                      cc (canna-context-kana-mode cc))
@@ -241,10 +243,43 @@
 		      canna-input-rule-azik))
 		 (lambda (cc)
 		   (canna-prepare-input-rule-activation cc)
+                   (require "japanese-azik.scm")
 		   (rk-context-set-rule! (canna-context-rkc cc)
 					 ja-azik-rule)
 		   (canna-context-set-input-rule! cc canna-input-rule-azik)))
 
+(register-action 'action_canna_kzik
+		 (lambda (cc)
+		   '(ja_kzik
+		     ""
+		     "KZIK"
+		     "KZIKĥ޻ϥ⡼"))
+		 (lambda (cc)
+		   (= (canna-context-input-rule cc)
+		      canna-input-rule-kzik))
+		 (lambda (cc)
+		   (canna-prepare-input-rule-activation cc)
+                   (require "japanese-kzik.scm")
+		   (rk-context-set-rule! (canna-context-rkc cc)
+					 ja-kzik-rule)
+		   (canna-context-set-input-rule! cc canna-input-rule-kzik)))
+
+(register-action 'action_canna_act
+		 (lambda (cc)
+		   '(ja_act
+		     ""
+		     "ACT"
+		     "ACTĥ޻ϥ⡼"))
+		 (lambda (cc)
+		   (= (canna-context-input-rule cc)
+		      canna-input-rule-act))
+		 (lambda (cc)
+		   (canna-prepare-input-rule-activation cc)
+                   (require "japanese-act.scm")
+		   (rk-context-set-rule! (canna-context-rkc cc)
+					 ja-act-rule)
+		   (canna-context-set-input-rule! cc canna-input-rule-act)))
+
 ;; Update widget definitions based on action configurations. The
 ;; procedure is needed for on-the-fly reconfiguration involving the
 ;; custom API
@@ -267,6 +302,7 @@
     (list 'state              #f)
     (list 'transposing        #f)
     (list 'transposing-type    0)
+    (list 'predicting         #f)
     (list 'cc-id              ()) ;; canna-context-id
     (list 'preconv-ustr	      #f) ;; preedit strings
     (list 'rkc                ())
@@ -278,10 +314,50 @@
     (list 'alnum-type	      canna-type-halfwidth-alnum)
     (list 'commit-raw         #t)
     (list 'input-rule         canna-input-rule-roma)
-    (list 'raw-ustr	      #f))))
+    (list 'raw-ustr	      #f)
+    (list 'prediction-ctx     '())
+    (list 'prediction-word    '())
+    (list 'prediction-candidates '())
+    (list 'prediction-appendix '())
+    (list 'prediction-nr      '())
+    (list 'prediction-window  #f)
+    (list 'prediction-index   #f)
+    (list 'prediction-cache   '()))))
 (define-record 'canna-context canna-context-rec-spec)
 (define canna-context-new-internal canna-context-new)
 
+(define (canna-predict cc str)
+  (predict-meta-search
+   (canna-context-prediction-ctx cc)
+   str))
+(define (canna-lib-set-prediction-src-string cc str)
+  (let* ((ret      (canna-predict cc str))
+         (word     (predict-meta-word? ret))
+         (cands    (predict-meta-candidates? ret))
+         (appendix (predict-meta-appendix? ret)))
+    (canna-context-set-prediction-word! cc word)
+    (canna-context-set-prediction-candidates! cc cands)
+    (canna-context-set-prediction-appendix! cc cands)
+    (canna-context-set-prediction-nr! cc (length cands)))
+  #f)
+(define (canna-lib-get-nr-predictions cc)
+  (canna-context-prediction-nr cc))
+(define (canna-lib-get-nth-word cc nth)
+  (let ((word (canna-context-prediction-word cc)))
+    (list-ref word nth)))
+(define (canna-lib-get-nth-prediction cc nth)
+  (let ((cands (canna-context-prediction-candidates cc)))
+    (list-ref cands nth)))
+(define (canna-lib-get-nth-appendix cc nth)
+  (let ((appendix (canna-context-prediction-candidates cc)))
+    (list-ref appendix nth)))
+(define (canna-lib-commit-nth-prediction cc nth)
+  (predict-meta-commit
+   (canna-context-prediction-ctx cc)
+   (canna-lib-get-nth-word cc nth)
+   (canna-lib-get-nth-prediction cc nth)
+   (canna-lib-get-nth-appendix cc nth)))
+
 (define (canna-context-new id im)
   (let ((cc (canna-context-new-internal id im))
 	(rkc (rk-context-new ja-rk-rule #t #f)))
@@ -293,9 +369,11 @@
     (canna-context-set-preconv-ustr! cc (ustr-new '()))
     (canna-context-set-raw-ustr! cc (ustr-new '()))
     (canna-context-set-segments! cc (ustr-new '()))
-    (if using-kana-table?
-        (canna-context-set-input-rule! cc canna-input-rule-kana)
-        (canna-context-set-input-rule! cc canna-input-rule-roma))
+    (if canna-use-prediction?
+        (begin
+          (canna-context-set-prediction-ctx! cc (predict-make-meta-search))
+          (predict-meta-open (canna-context-prediction-ctx cc) "canna")
+          (predict-meta-set-external-charset! (canna-context-prediction-ctx cc) "EUC-JP")))
     cc))
 
 (define (canna-commit-raw cc)
@@ -344,8 +422,10 @@
 	      (string-append-map-ustr-former extract-kana preconv-str)
 	      (if convert-pending-into-kana?
 		  (if residual-kana
-		      (extract-kana residual-kana)
-                      pending)
+                    (if (list? (car residual-kana))
+                      (string-append-map extract-kana residual-kana)
+		      (extract-kana residual-kana))
+                    pending)
 		  pending)
               (string-append-map-ustr-latter extract-kana preconv-str))))
 	   kana)
@@ -353,8 +433,10 @@
 	   (string-append-map-ustr-former extract-kana preconv-str)
            (if convert-pending-into-kana?
                (if residual-kana
-                   (extract-kana residual-kana)
-                   "")
+                 (if (list? (car residual-kana))
+                   (string-append-map extract-kana residual-kana)
+                   (extract-kana residual-kana))
+                 "")
                pending)
            (string-append-map-ustr-latter extract-kana preconv-str))))))
 
@@ -405,9 +487,11 @@
   (ustr-clear! (canna-context-segments cc))
   (canna-context-set-transposing! cc #f)
   (canna-context-set-state! cc #f)
-  (if (canna-context-candidate-window cc)
+  (if (or (canna-context-candidate-window cc)
+          (canna-context-prediction-window cc))
       (im-deactivate-candidate-selector cc))
   (canna-context-set-candidate-window! cc #f)
+  (canna-context-set-prediction-window! cc #f)
   (canna-context-set-candidate-op-count! cc 0))
 
 (define (canna-begin-input cc key key-state)
@@ -462,7 +546,9 @@
 			      (canna-context-transposing-state-preedit cc)
 			      (if (canna-context-state cc)
 				  (canna-compose-state-preedit cc)
-				  (canna-input-state-preedit cc)))
+                                  (if (canna-context-predicting cc)
+                                      (canna-predicting-state-preedit cc)
+                                      (canna-input-state-preedit cc))))
 			  ())))
 	(context-update-preedit cc segments))
       (canna-context-set-commit-raw! cc #f)))
@@ -604,7 +690,9 @@
 	         (res (rk-push-key! rkc key-str)))
 	    (if res
 	        (begin
-	          (ustr-insert-elem! (canna-context-preconv-ustr cc) res)
+                  (if (list? (car res))
+                    (ustr-insert-seq! (canna-context-preconv-ustr cc) res)
+                    (ustr-insert-elem! (canna-context-preconv-ustr cc) res))
 	          (ustr-insert-elem! (canna-context-raw-ustr cc) key-str))
 	        (if (null? (rk-context-seq rkc))
 		    (canna-commit-raw cc)))))))))
@@ -717,7 +805,185 @@
 	   (canna-flush cc)
 	   (canna-proc-input-state cc key key-state))))))))
 
+(define (canna-move-prediction cc offset)
+  (let* ((nr (canna-lib-get-nr-predictions cc))
+         (idx (canna-context-prediction-index cc))
+         (n (if (not idx)
+                0
+                (+ idx offset)))
+         (compensated-n (cond
+                         ((>= n nr)
+                          0)
+                        ((< n 0)
+                         (- nr 1))
+                        (else
+                         n))))
+    (im-select-candidate cc compensated-n)
+    (canna-context-set-prediction-index! cc compensated-n)))
+
+(define (canna-move-prediction-in-page sc numeralc)
+  (let* ((nr (canna-lib-get-nr-predictions sc))
+         (p-idx (canna-context-prediction-index sc))
+         (n (if (not p-idx)
+                0
+                p-idx))
+         (cur-page (if (= canna-nr-candidate-max 0)
+                       0
+                       (quotient n canna-nr-candidate-max)))
+         (pageidx (- (numeric-ichar->integer numeralc) 1))
+         (compensated-pageidx (cond
+                               ((< pageidx 0) ; pressing key_0
+                                (+ pageidx 10))
+                               (else
+                                pageidx)))
+         (idx (+ (* cur-page canna-nr-candidate-max) compensated-pageidx))
+         (compensated-idx (cond
+                           ((>= idx nr)
+                            #f)
+                           (else
+                            idx)))
+         (selected-pageidx (if (not p-idx)
+                               #f
+                               (if (= canna-nr-candidate-max 0)
+                                   p-idx
+                                   (remainder p-idx
+                                              canna-nr-candidate-max)))))
+    (if (and
+         compensated-idx
+         (not (eqv? compensated-pageidx selected-pageidx)))
+        (begin
+          (canna-context-set-prediction-index! sc compensated-idx)
+          (im-select-candidate sc compensated-idx)
+          #t)
+       #f)))
+
+(define (canna-prediction-select-non-existing-index? cc numeralc)
+  (let* ((nr (canna-lib-get-nr-predictions cc))
+         (p-idx (canna-context-prediction-index cc))
+         (cur-page (if (= canna-nr-candidate-max 0)
+                       0
+                       (quotient p-idx canna-nr-candidate-max)))
+         (pageidx (- (numeric-ichar->integer numeralc) 1))
+         (compensated-pageidx (cond
+                               ((< pageidx 0) ; pressing key_0
+                                (+ pageidx 10))
+                               (else
+                                pageidx)))
+         (idx (+ (* cur-page canna-nr-candidate-max) compensated-pageidx)))
+    (if (>= idx nr)
+        #t
+        #f)))
+
+(define (canna-prediction-keys-handled? cc key key-state)
+  (cond
+   ((canna-next-prediction-key? key key-state)
+    (canna-move-prediction cc 1)
+    #t)
+   ((canna-prev-prediction-key? key key-state)
+    (canna-move-prediction cc -1)
+    #t)
+   ((and
+     canna-select-prediction-by-numeral-key?
+     (ichar-numeric? key))
+    (canna-move-prediction-in-page cc key))
+   ((and
+     (canna-context-prediction-index cc)
+     (canna-prev-page-key? key key-state))
+    (im-shift-page-candidate cc #f)
+    #t)
+   ((and
+     (canna-context-prediction-index cc)
+     (canna-next-page-key? key key-state))
+    (im-shift-page-candidate cc #t)
+    #t)
+   (else
+    #f)))
+
+(define (canna-proc-prediction-state cc key key-state)
+  (cond
+   ;; prediction index change
+   ((canna-prediction-keys-handled? cc key key-state))
+
+   ;; cancel
+   ((canna-cancel-key? key key-state)
+    (if (canna-context-prediction-index cc)
+        (canna-reset-prediction-window cc)
+        (begin
+          (canna-reset-prediction-window cc)
+          (canna-proc-input-state cc key key-state))))
+
+   ;; commit
+   ((and
+     (canna-context-prediction-index cc)
+     (canna-commit-key? key key-state))
+    (canna-do-commit-prediction cc))
+   (else
+    (if (and
+         canna-use-implicit-commit-prediction?
+         (canna-context-prediction-index cc))
+        (cond
+         ((or
+           ;; check keys used in canna-proc-input-state-with-preedit
+           (canna-begin-conv-key? key key-state)
+           (canna-backspace-key? key key-state)
+           (canna-delete-key? key key-state)
+           (canna-kill-key? key key-state)
+           (canna-kill-backward-key? key key-state)
+           (and
+            (not (canna-context-alnum cc))
+            (canna-commit-as-opposite-kana-key? key key-state))
+           (canna-transpose-as-hiragana-key? key key-state)
+           (canna-transpose-as-katakana-key? key key-state)
+           (canna-transpose-as-halfkana-key? key key-state)
+           (and
+            (not (= (canna-context-input-rule cc) canna-input-rule-kana))
+            (or
+             (canna-transpose-as-halfwidth-alnum-key? key key-state)
+             (canna-transpose-as-fullwidth-alnum-key? key key-state)))
+           (canna-hiragana-key? key key-state)
+           (canna-katakana-key? key key-state)
+           (canna-halfkana-key? key key-state)
+           (canna-halfwidth-alnum-key? key key-state)
+           (canna-fullwidth-alnum-key? key key-state)
+           (and
+            (not (canna-context-alnum cc))
+            (canna-kana-toggle-key? key key-state))
+           (canna-alkana-toggle-key? key key-state)
+           (canna-go-left-key? key key-state)
+           (canna-go-right-key? key key-state)
+           (canna-beginning-of-preedit-key? key key-state)
+           (canna-end-of-preedit-key? key key-state)
+           (and
+            (modifier-key-mask key-state)
+            (not (shift-key-mask key-state))))
+          ;; go back to unselected prediction
+          (canna-reset-prediction-window cc)
+          (canna-check-prediction cc #f))
+         ((and
+           (ichar-numeric? key)
+           canna-select-prediction-by-numeral-key?
+           (not (canna-prediction-select-non-existing-index? cc key)))
+          (canna-context-set-predicting! cc #f)
+          (canna-context-set-prediction-index! cc #f)
+          (canna-proc-input-state cc key key-state))
+         (else
+          ;; implicit commit
+          (canna-do-commit-prediction cc)
+          (canna-proc-input-state cc key key-state)))
+        (begin
+          (canna-context-set-predicting! cc #f)
+          (canna-context-set-prediction-index! cc #f)
+          (canna-proc-input-state cc key key-state))))))
+
 (define (canna-proc-input-state-with-preedit cc key key-state)
+  (define (check-auto-conv str)
+    (and
+      str
+      canna-auto-start-henkan?
+      (string-find japanese-auto-start-henkan-keyword-list str)
+      (begin
+	(canna-reset-prediction-window cc)
+	(canna-begin-conv cc))))
   (let ((preconv-str (canna-context-preconv-ustr cc))
 	(raw-str (canna-context-raw-ustr cc))
 	(rkc (canna-context-rkc cc))
@@ -726,8 +992,13 @@
     (cond
      ;; begin conversion
      ((canna-begin-conv-key? key key-state)
+      (canna-reset-prediction-window cc)
       (canna-begin-conv cc))
 
+     ;; prediction
+     ((canna-next-prediction-key? key key-state)
+      (canna-check-prediction cc #t))
+
      ;; backspace
      ((canna-backspace-key? key key-state)
       (if (not (rk-backspace rkc))
@@ -777,6 +1048,7 @@
 	   (or
 	    (canna-transpose-as-halfwidth-alnum-key? key key-state)
 	    (canna-transpose-as-fullwidth-alnum-key? key key-state))))
+      (canna-reset-prediction-window cc)
       (canna-proc-transposing-state cc key key-state))
 
      ((canna-hiragana-key? key key-state)
@@ -877,22 +1149,6 @@
       #f)
 
      (else
-      ;; handle "n1" sequence as "1"
-      (if (and (not (canna-context-alnum cc))
-	       (not (ichar-alphabetic? key))
-	       (not (string-find
-		     (rk-expect rkc)
-		     (charcode->string
-		      (if (= rule canna-input-rule-kana)
-			  key
-			  (ichar-downcase key))))))
-	  (let ((pend (rk-pending rkc))
-		(residual-kana (rk-push-key-last! rkc)))
-	    (if residual-kana
-		(begin
-		  (ustr-insert-elem! preconv-str residual-kana)
-		  (ustr-insert-elem! raw-str pend)))))
-
       (if (canna-context-alnum cc)
           (let ((key-str (charcode->string key))
 	        (pend (rk-pending rkc))
@@ -900,15 +1156,22 @@
 	    (rk-flush rkc) ;; OK to reset rkc here.
 	    (if residual-kana
 	        (begin
-		  (ustr-insert-elem! preconv-str residual-kana)
-		  (ustr-insert-elem! raw-str pend)))
+                  (if (list? (car residual-kana))
+                    (begin
+                      (ustr-insert-seq! preconv-str residual-kana)
+                      (ustr-insert-elem! raw-str (reverse
+                                                   (string-to-list pend))))
+                    (begin
+                      (ustr-insert-elem! preconv-str residual-kana)
+                      (ustr-insert-elem! raw-str pend)))))
 	    (ustr-insert-elem! preconv-str
 			       (if (= (canna-context-alnum-type cc)
 				      canna-type-halfwidth-alnum)
 				   (list key-str key-str key-str)
 				   (list (ja-wide key-str) (ja-wide key-str)
 					 (ja-wide key-str))))
-	    (ustr-insert-elem! raw-str key-str))
+	    (ustr-insert-elem! raw-str key-str)
+	    (check-auto-conv key-str))
 	  (let* ((key-str (charcode->string
 			   (if (= rule canna-input-rule-kana)
 			       key
@@ -924,14 +1187,25 @@
 		      (ustr-insert-elem! preconv-str res))
 	          (if (and next-pend
 		           (not (string=? next-pend "")))
-		      (ustr-insert-elem! raw-str pend)
+		      (ustr-insert-seq! raw-str
+                                        (reverse (string-to-list pend)))
 		      (if (list? (car res))
 		          (begin
-			    (ustr-insert-elem! raw-str pend)
+                            (if (member pend
+                                        (map car
+                                             ja-consonant-syllable-table))
+                              ;; treat consonant having more than one
+                              ;; charactear as one raw-str in this case
+                              (ustr-insert-elem! raw-str pend)
+                              (ustr-insert-elem! raw-str (reverse
+                                                           (string-to-list
+                                                             pend))))
+                            ;; assume key-str as a vowel
 			    (ustr-insert-elem! raw-str key-str))
 		          (ustr-insert-elem!
 		           raw-str
-		           (string-append pend key-str))))))))))))
+		           (string-append pend key-str))))))
+	    (check-auto-conv (if res (car res) #f))))))))
 
 (define canna-context-confirm-kana!
   (lambda (cc)
@@ -942,13 +1216,59 @@
 	       (residual-kana (rk-peek-terminal-match rkc)))
 	  (if residual-kana
 	      (begin
-		(ustr-insert-elem! preconv-str residual-kana)
+                (if (list? (car residual-kana))
+                  (ustr-insert-seq! preconv-str residual-kana)
+                  (ustr-insert-elem! preconv-str residual-kana))
 		(rk-flush rkc)))))))
 
+(define (canna-reset-prediction-window cc)
+  (if (canna-context-prediction-window cc)
+      (im-deactivate-candidate-selector cc))
+  (canna-context-set-predicting! cc #f)
+  (canna-context-set-prediction-window! cc #f)
+  (canna-context-set-prediction-index! cc #f))
+
+(define (canna-check-prediction cc force-check?)
+  (if (and
+       (not (canna-context-state cc))
+       (not (canna-context-transposing cc))
+       (not (canna-context-predicting cc)))
+      (let* ((use-pending-rk-for-prediction? #t)
+	     (preconv-str
+	      (canna-make-whole-string
+	       cc
+	       (not use-pending-rk-for-prediction?)
+	       (canna-context-kana-mode cc)))
+	     (preedit-len (+
+			   (ustr-length (canna-context-preconv-ustr cc))
+			   (if (not use-pending-rk-for-prediction?)
+			       0
+			       (string-length (rk-pending
+					       (canna-context-rkc
+						cc)))))))
+	(if (or
+	     (>= preedit-len canna-prediction-start-char-count)
+	     force-check?)
+	    (begin
+	      (canna-lib-set-prediction-src-string cc preconv-str)
+	      (let ((nr (canna-lib-get-nr-predictions cc)))
+		(if (and
+		     nr
+		     (> nr 0))
+		    (begin
+		      (im-activate-candidate-selector
+		       cc nr canna-nr-candidate-max)
+		      (canna-context-set-prediction-window! cc #t)
+		      (canna-context-set-predicting! cc #t))
+		    (canna-reset-prediction-window cc))))
+	    (canna-reset-prediction-window cc)))))
+
 (define (canna-proc-input-state cc key key-state)
   (if (canna-has-preedit? cc)
       (canna-proc-input-state-with-preedit cc key key-state)
-      (canna-proc-input-state-no-preedit cc key key-state)))
+      (canna-proc-input-state-no-preedit cc key key-state))
+  (if canna-use-prediction?
+      (canna-check-prediction cc #f)))
 
 (define canna-separator
   (lambda (cc)
@@ -991,8 +1311,10 @@
 	   (left-str (ustr-former-seq raw-str)))
      (append left-str
 	     (if residual-kana
-		 (list pending)
-		 '())
+               (if (list? (car residual-kana))
+                 (reverse (string-to-list pending))
+		 (list pending))
+               '())
 	      right-str))))
 
 (define canna-get-raw-candidate
@@ -1017,7 +1339,9 @@
 	    (if (member (car unconv) preconv)
 		(let ((start (list-seq-contained? preconv unconv))
 		      (len (length unconv)))
-		  (if start
+		  (if (and
+                        start
+                        (= (length raw-str) (length preconv))) ;; sanity check
 		      (canna-make-raw-string
 		       (reverse (sublist-rel raw-str start len))
 		       (if (or
@@ -1035,6 +1359,14 @@
 		"???") ;; FIXME
 	    "????")))))) ;; shouldn't happen
 
+(define (canna-predicting-state-preedit cc)
+  (if (or
+       (not canna-use-implicit-commit-prediction?)
+       (not (canna-context-prediction-index cc)))
+      (canna-input-state-preedit cc)
+      (let ((cand (canna-get-prediction-string cc)))
+        (list (cons (bitwise-ior preedit-reverse preedit-cursor) cand)))))
+
 (define (canna-compose-state-preedit cc)
   (let* ((cc-id (canna-context-cc-id cc))
 	 (segments (canna-context-segments cc))
@@ -1111,6 +1443,22 @@
     (canna-reset-candidate-window cc)
     (canna-flush cc))
 
+(define (canna-get-prediction-string cc)
+  (canna-lib-get-nth-prediction
+   cc
+   (canna-context-prediction-index cc)))
+
+(define (canna-learn-prediction-string cc)
+  (canna-lib-commit-nth-prediction
+   cc
+   (canna-context-prediction-index cc)))
+
+(define (canna-do-commit-prediction cc)
+  (im-commit cc (canna-get-prediction-string cc))
+  (canna-learn-prediction-string cc)
+  (canna-reset-prediction-window cc)
+  (canna-flush cc))
+
 (define canna-correct-segment-cursor
   (lambda (segments)
     (if (ustr-cursor-at-end? segments)
@@ -1333,7 +1681,9 @@
               (canna-proc-transposing-state cc key key-state)
               (if (canna-context-state cc)
                   (canna-proc-compose-state cc key key-state)
-                  (canna-proc-input-state cc key key-state)))
+                  (if (canna-context-predicting cc)
+                      (canna-proc-prediction-state cc key key-state)
+                      (canna-proc-input-state cc key key-state))))
 	  (canna-proc-raw-state cc key key-state)))
   (canna-update-preedit cc))
 
@@ -1355,13 +1705,19 @@
 (define (canna-get-candidate-handler cc idx accel-enum-hint)
   (let* ((cc-id (canna-context-cc-id cc))
 	 (cur-seg (ustr-cursor-pos (canna-context-segments cc)))
-	 (cand (canna-lib-get-nth-candidate
-		cc-id cur-seg idx)))
+         (cand (if (canna-context-state cc)
+                   (canna-lib-get-nth-candidate cc-id cur-seg idx)
+                   (canna-lib-get-nth-prediction cc idx))))
     (list cand (digit->string (+ idx 1)) "")))
 
 (define (canna-set-candidate-index-handler cc idx)
-  (ustr-cursor-set-frontside! (canna-context-segments cc) idx)
-  (canna-update-preedit cc))
+  (cond
+   ((canna-context-state cc)
+    (ustr-cursor-set-frontside! (canna-context-segments cc) idx)
+    (canna-update-preedit cc))
+   ((canna-context-predicting cc)
+    (canna-context-set-prediction-index! cc idx)
+    (canna-update-preedit cc))))
 
 (define (canna-proc-raw-state cc key key-state)
   (if (not (canna-begin-input cc key key-state))
