@@ -1,6 +1,6 @@
 ;;; im-custom.scm: Customization variables for im.scm
 ;;;
-;;; Copyright (c) 2003-2008 uim Project http://code.google.com/p/uim/
+;;; Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 ;;;
 ;;; All rights reserved.
 ;;;
@@ -29,7 +29,10 @@
 ;;; SUCH DAMAGE.
 ;;;;
 
+(require-extension (srfi 1 34))
+
 (require "i18n.scm")
+(require "xkb.scm")
 
 (define custom-im-list-as-choice-rec
   (lambda (lst)
@@ -49,6 +52,26 @@
 		     (N_ "Toolbar")
 		     (N_ "long description will be here."))
 
+(define-custom-group 'annotation
+                     (N_ "Annotation")
+                     (N_ "long description will be here."))
+
+(define-custom-group 'xim
+		     (N_ "XIM")
+		     (N_ "long description will be here."))
+
+(define-custom-group 'xkb
+		     (N_ "Xkb")
+		     (N_ "long description will be here."))
+
+(define-custom-group 'notify
+		     (N_ "Notify")
+		     (N_ "long description will be here."))
+
+(define-custom-group 'http
+		     (N_ "Http")
+		     (N_ "long description will be here."))
+
 ;; subgroup
 (define-custom-group 'advanced
 		     (N_ "Advanced settings")
@@ -69,11 +92,6 @@
 		     (N_ "Candidate window")
 		     (N_ "long description will be here."))
 
-;; subgroup
-(define-custom-group 'annotation
-                     (N_ "Annotation")
-                     (N_ "long description will be here."))
-
 ;; subgroup
 (define-custom-group 'dictionary
                      (N_ "Dictionary")
@@ -109,6 +127,37 @@
 		     (N_ "Visual preference")
 		     (N_ "long description will be here."))
 
+;; subgroup
+(define-custom-group 'xim-preedit
+		     (N_ "Preedit settings of XIM")
+		     (N_ "long description will be here."))
+
+;; subgroup
+(define-custom-group 'xkb-preference
+		     (N_ "Settings of X Keyboard Extension")
+		     (N_ "long description will be here."))
+
+;; subgroup
+(define-custom-group 'toolbar-help
+                     (N_ "Help")
+                     (N_ "long description will be here."))
+
+;; subgroup
+(define-custom-group 'toolbar-icon
+                     (N_ "Icon")
+                     (N_ "long description will be here."))
+
+;; subgroup
+(define-custom-group 'toolbar-display
+                     (N_ "Display behavior")
+                     (N_ "long description will be here."))
+
+;; subgroup
+(define-custom-group 'toolbar-widget
+                     (N_ "Toolbar")
+                     (N_ "long description will be here."))
+
+
 ;; 
 ;; default-im-name
 ;;
@@ -278,7 +327,7 @@
   (N_ "Input method switching")
   (N_ "long description will be here."))
 
-(define-custom 'enable-im-switch #f
+(define-custom 'enable-im-switch? #f
   '(global im-switching)
   '(boolean)
   (N_ "Enable IM switching by hotkey")
@@ -297,15 +346,15 @@
   (N_ "long description will be here."))
 
 ;; activity dependency
-(custom-add-hook 'switch-im-key?
+(custom-add-hook 'switch-im-key
 		 'custom-activity-hooks
 		 (lambda ()
-		   enable-im-switch))
+		   enable-im-switch?))
 
 (custom-add-hook 'switch-im-skip-direct-im?
 		 'custom-activity-hooks
 		 (lambda ()
-		   enable-im-switch))
+		   enable-im-switch?))
 
 ;; im-toggle 
 (define-custom-group 'im-toggle
@@ -367,6 +416,21 @@
 		 (lambda ()
 		   (update-style uim-color-spec (symbol-value uim-color))))
 
+(define-custom 'candidate-window-style 'vertical
+  '(global visual-preference)
+  (list 'choice
+	(list 'vertical
+	      (N_ "Vertical")
+	      (N_ "long description will be here"))
+	(list 'horizontal
+	      (N_ "Horizontal")
+	      (N_ "long description will be here"))
+	(list 'table
+	      (N_ "Table style")
+	      (N_ "long description will be here")))
+  (N_ "Candidate window type")
+  (N_ "long description will be here."))
+
 ;; referred by some bridges
 (define-custom 'candidate-window-position 'caret
   '(global visual-preference)
@@ -395,6 +459,21 @@
 		   (if enable-lazy-loading?
 		       (require "lazy-load.scm"))))
 
+(define-custom 'toolbar-display-time 'always
+  '(toolbar toolbar-display)
+  (list 'choice
+        (list 'always
+              (N_ "Always")
+              (N_ "long description will be here."))
+        (list 'mode
+              (N_ "Based on mode")
+              (N_ "long description will be here."))
+        (list 'never
+              (N_ "Never")
+              (N_ "long description will be here.")))
+  (N_ "Display")
+  (N_ "long description will be here."))
+
 ;;
 ;; toolbar buttons
 ;;
@@ -480,12 +559,58 @@
   (N_ "help")
   (N_ "long description will be here."))
 
+(define-custom 'toolbar-help-browser 'system
+  '(toolbar toolbar-help)
+  (list 'choice
+        (list 'system
+              (N_ "System")
+              (N_ "long description will be here."))
+        (list 'manual
+              (N_ "Manual")
+              (N_ "long description will be here.")))
+  (N_ "Document browser")
+  (N_ "long description will be here."))
+
+(define-custom 'toolbar-help-browser-name "firefox"
+  '(toolbar toolbar-help)
+  '(string ".*")
+  (N_ "Browser name")
+  (N_ "long description will be here."))
+
+(custom-add-hook 'toolbar-help-browser-name
+		 'custom-activity-hooks
+		 (lambda ()
+                   (eq? toolbar-help-browser 'manual)))
+
+(define-custom 'toolbar-icon-for-dark-background? #f
+  '(toolbar toolbar-icon)
+  '(boolean)
+  (N_ "Use icon for dark background")
+  (N_ "long description will be here."))
+
 (define-custom 'bridge-show-input-state? #f
   '(global visual-preference)
   '(boolean)
   (N_ "Show input mode nearby cursor")
   (N_ "long description will be here."))
 
+(define-custom 'bridge-show-with? 'time
+  '(global visual-preference)
+  (list 'choice
+        (list 'mode
+              (N_ "With mode")
+              (N_ "long description will be here."))
+        (list 'time
+              (N_ "With time")
+              (N_ "long description will be here.")))
+  (N_ "Show input mode")
+  (N_ "long description will be here."))
+
+(custom-add-hook 'bridge-show-with?
+		 'custom-activity-hooks
+		 (lambda ()
+                   bridge-show-input-state?))
+
 (define-custom 'bridge-show-input-state-time-length 3
   '(global visual-preference)
   '(integer 0 100)
@@ -495,50 +620,22 @@
 (custom-add-hook 'bridge-show-input-state-time-length
 		 'custom-activity-hooks
 		 (lambda ()
-		   bridge-show-input-state?))
-
-;; EB Library support
-;; 2005-02-08 Takuro Ashie <ashie@homa.ne.jp>
-;; FIXME! Here isn't suitable position for EB support preference
-(define-custom-group 'eb
-		     (N_ "EB library")
-		     (N_ "long description will be here."))
-
-(define-custom 'eb-enable-for-annotation? #f
-  '(eb candwin)
-  '(boolean)
-  (N_ "Use EB library to search annotations")
-  (N_ "long description will be here."))
-
-(define-custom 'eb-dic-path
-  (string-append (sys-datadir) "/dict")
-  '(eb candwin)
-  '(pathname directory)
-  (N_ "The directory which contains EB dictionary file")
-  (N_ "long description will be here."))
-
-(custom-add-hook 'eb-dic-path
-		 'custom-activity-hooks
-		 (lambda ()
-		   eb-enable-for-annotation?))
+		   (and bridge-show-input-state?
+                        (eq? bridge-show-with?
+                             'time))))
 
+;;
 ;; uim-xim specific custom
-(define-custom-group 'xim
-		     (N_ "XIM")
-		     (N_ "long description will be here."))
-
-(define-custom-group 'preedit
-		     (N_ "Preedit settings of XIM")
-		     (N_ "long description will be here."))
+;;
 
 (define-custom 'uim-xim-use-xft-font? #f
-  '(xim preedit)
+  '(xim xim-preedit)
   '(boolean)
   (N_ "Use anti-aliased fonts for Over-the-Spot/Root-Window preedit")
   (N_ "long description will be here."))
 
 (define-custom 'uim-xim-xft-font-name "Sans"
-  '(xim preedit)
+  '(xim xim-preedit)
   '(string ".*")
   (N_ "Font name for preedit area (anti-aliased)")
   (N_ "long description will be here."))
@@ -548,10 +645,47 @@
 		 (lambda ()
 		   uim-xim-use-xft-font?))
 
+;;
+;; X Keyboard Extension specific custom
+;;
 
-(define-custom-group 'notify
-		     (N_ "Notify")
-		     (N_ "long description will be here."))
+(define-custom 'xkb-save-map? #f
+  '(xkb xkb-preference)
+  '(boolean)
+  (N_ "Save keyboard map to load in Xkb-less environments")
+  (N_ "long description will be here."))
+
+(custom-add-hook 'xkb-save-map?
+		 'custom-activity-hooks
+		 (lambda ()
+		   (and xkb-plugin-ready? (xkb-lib-display-ready?))))
+
+(custom-add-hook 'xkb-save-map?
+		 'custom-set-hooks
+		 (lambda ()
+		   (if xkb-save-map?
+		       (let ((m (xkb-lib-get-map)))
+			 (if m (guard (err
+				       (else #f))
+				      (get-config-path! #t)
+				      (call-with-output-file xkb-map-path
+					(lambda (p) (write m p)))))))))
+
+(define-custom 'xkb-map-path
+  (string-append (or (get-config-path #t) "") "/xkb-map")
+  '(xkb xkb-preference)
+  '(pathname regular-file)
+  (N_ "Location of keyboard map file")
+  (N_ "long description will be here."))
+
+(custom-add-hook 'xkb-map-path
+		 'custom-activity-hooks
+		 (lambda ()
+		   xkb-plugin-ready?))
+
+;;
+;; Notify
+;;
 
 (define-custom 'notify-agent 'stderr
   '(notify)
@@ -560,6 +694,65 @@
   (N_ "Notify agent name")
   (N_ "long description will be here."))
 
+(custom-add-hook 'notify-agent
+                 'custom-set-hooks
+                 (lambda ()
+                   (if (symbol-bound? 'uim-notify-load)
+                     (uim-notify-load (symbol->string
+                                        notify-agent)))))
+
+;;
+;; Http
+;;
+
+(define-custom 'http-proxy-setting 'direct
+  '(http)
+  (list 'choice
+        (list 'direct
+              (N_ "Direct connection")
+              (N_ "Direct connection, no proxy."))
+        (list 'user
+              (N_ "User")
+              (N_ "Use proxy."))
+        ;;(list 'system
+        ;;      (N_ "System")
+        ;;      (N_ "Use proxy with system setting.")))
+        )
+  (N_ "Proxy setting")
+  (N_ "long description will be here."))
+
+(define-custom 'http-proxy-hostname "localhost"
+  '(http)
+  '(string ".*")
+  (N_ "Http proxy hostname")
+  (N_ "long description will be here."))
+
+(custom-add-hook 'http-proxy-hostname
+		 'custom-activity-hooks
+		 (lambda ()
+                   (eq? http-proxy-setting
+                        'user)))
+
+(define-custom 'http-proxy-port 8080
+  '(http)
+  '(integer 0 65535)
+  (N_ "Http proxy port")
+  (N_ "long description will be here."))
+
+(custom-add-hook 'http-proxy-port
+		 'custom-activity-hooks
+		 (lambda ()
+                   (eq? http-proxy-setting
+                        'user)))
+
+(define-custom 'http-timeout 3000
+  '(http)
+  '(integer 0 65535)
+  (N_ "Timeout (msec)")
+  (N_ "Timeout of http connection (msec)."))
+
+(load "predict-custom.scm")
+
 
 (if custom-full-featured?
     (for-each require-module installed-im-module-list))
