@@ -1,5 +1,5 @@
 ;;;
-;;; Copyright (c) 2003-2008 uim Project http://code.google.com/p/uim/
+;;; Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
 ;;;
 ;;; All rights reserved.
 ;;;
@@ -33,23 +33,23 @@
 ;;
 (define tcode-rule
   '(
-    ((("1" "1"))(""))
-    ((("2" "1"))(""))
-    ((("3" "1"))(""))
-    ((("4" "1"))(""))
-    ((("5" "1"))(""))
-    ((("6" "1"))(""))
-    ((("7" "1"))(""))
-    ((("8" "1"))(""))
-    ((("9" "1"))(""))
-    ((("0" "1"))(""))
+    ;((("1" "1"))(""))
+    ;((("2" "1"))(""))
+    ;((("3" "1"))(""))
+    ;((("4" "1"))(""))
+    ;((("5" "1"))(""))
+    ;((("6" "1"))(""))
+    ;((("7" "1"))(""))
+    ;((("8" "1"))(""))
+    ;((("9" "1"))(""))
+    ;((("0" "1"))(""))
     ((("," "1"))(""))
     ((("." "1"))(""))
     ((("p" "1"))(""))
     ((("y" "1"))(""))
-    ((("f" "1"))(""))
-    ((("g" "1"))(""))
-    ((("c" "1"))(""))
+    ;((("f" "1"))(""))
+    ;((("g" "1"))(""))
+    ;((("c" "1"))(""))
     ((("r" "1"))(""))
     ((("l" "1"))(""))
     ((("a" "1"))(""))
@@ -66,30 +66,30 @@
     ((("q" "1"))(""))
     ((("j" "1"))(""))
     ((("k" "1"))(""))
-    ((("x" "1"))(""))
-    ((("b" "1"))(""))
+    ;((("x" "1"))(""))
+    ;((("b" "1"))(""))
     ((("m" "1"))(""))
     ((("w" "1"))(""))
-    ((("v" "1"))(""))
-    ((("z" "1"))(""))
+    ;((("v" "1"))(""))
+    ;((("z" "1"))(""))
     ((("/" "1"))(""))
-    ((("1" "2"))(""))
-    ((("2" "2"))(""))
-    ((("3" "2"))(""))
-    ((("4" "2"))(""))
-    ((("5" "2"))(""))
-    ((("6" "2"))(""))
-    ((("7" "2"))(""))
-    ((("8" "2"))(""))
-    ((("9" "2"))(""))
-    ((("0" "2"))(""))
+    ;((("1" "2"))(""))
+    ;((("2" "2"))(""))
+    ;((("3" "2"))(""))
+    ;((("4" "2"))(""))
+    ;((("5" "2"))(""))
+    ;((("6" "2"))(""))
+    ;((("7" "2"))(""))
+    ;((("8" "2"))(""))
+    ;((("9" "2"))(""))
+    ;((("0" "2"))(""))
     ((("," "2"))(""))
     ((("." "2"))(""))
     ((("p" "2"))(""))
     ((("y" "2"))(""))
     ((("f" "2"))(""))
-    ((("g" "2"))(""))
-    ((("c" "2"))(""))
+    ;((("g" "2"))(""))
+    ;((("c" "2"))(""))
     ((("r" "2"))(""))
     ((("l" "2"))(""))
     ((("a" "2"))(""))
@@ -106,30 +106,30 @@
     ((("q" "2"))(""))
     ((("j" "2"))(""))
     ((("k" "2"))(""))
-    ((("x" "2"))(""))
-    ((("b" "2"))(""))
+    ;((("x" "2"))(""))
+    ;((("b" "2"))(""))
     ((("m" "2"))(""))
     ((("w" "2"))(""))
-    ((("v" "2"))(""))
-    ((("z" "2"))(""))
+    ;((("v" "2"))(""))
+    ;((("z" "2"))(""))
     ((("/" "2"))(""))
-    ((("1" "3"))(""))
-    ((("2" "3"))(""))
-    ((("3" "3"))(""))
-    ((("4" "3"))(""))
-    ((("5" "3"))(""))
-    ((("6" "3"))(""))
-    ((("7" "3"))(""))
-    ((("8" "3"))(""))
-    ((("9" "3"))(""))
-    ((("0" "3"))(""))
+    ;((("1" "3"))(""))
+    ;((("2" "3"))(""))
+    ;((("3" "3"))(""))
+    ;((("4" "3"))(""))
+    ;((("5" "3"))(""))
+    ;((("6" "3"))(""))
+    ;((("7" "3"))(""))
+    ;((("8" "3"))(""))
+    ;((("9" "3"))(""))
+    ;((("0" "3"))(""))
     ((("," "3"))(""))
     ((("." "3"))(""))
     ((("p" "3"))(""))
     ((("y" "3"))(""))
     ((("f" "3"))(""))
     ((("g" "3"))(""))
-    ((("c" "3"))(""))
+    ;((("c" "3"))(""))
     ((("r" "3"))(""))
     ((("l" "3"))(""))
     ((("a" "3"))(""))
@@ -146,30 +146,30 @@
     ((("q" "3"))(""))
     ((("j" "3"))(""))
     ((("k" "3"))(""))
-    ((("x" "3"))(""))
-    ((("b" "3"))(""))
+    ;((("x" "3"))(""))
+    ;((("b" "3"))(""))
     ((("m" "3"))(""))
     ((("w" "3"))(""))
-    ((("v" "3"))(""))
-    ((("z" "3"))(""))
+    ;((("v" "3"))(""))
+    ;((("z" "3"))(""))
     ((("/" "3"))(""))
-    ((("1" "4"))(""))
-    ((("2" "4"))(""))
-    ((("3" "4"))(""))
-    ((("4" "4"))(""))
-    ((("5" "4"))(""))
-    ((("6" "4"))(""))
-    ((("7" "4"))(""))
-    ((("8" "4"))(""))
-    ((("9" "4"))(""))
-    ((("0" "4"))(""))
+    ;((("1" "4"))(""))
+    ;((("2" "4"))(""))
+    ;((("3" "4"))(""))
+    ;((("4" "4"))(""))
+    ;((("5" "4"))(""))
+    ;((("6" "4"))(""))
+    ;((("7" "4"))(""))
+    ;((("8" "4"))(""))
+    ;((("9" "4"))(""))
+    ;((("0" "4"))(""))
     ((("," "4"))("ɧ"))
     ((("." "4"))(""))
     ((("p" "4"))(""))
     ((("y" "4"))(""))
     ((("f" "4"))(""))
     ((("g" "4"))(""))
-    ((("c" "4"))(""))
+    ;((("c" "4"))(""))
     ((("r" "4"))(""))
     ((("l" "4"))(""))
     ((("a" "4"))(""))
@@ -186,107 +186,107 @@
     ((("q" "4"))(""))
     ((("j" "4"))(""))
     ((("k" "4"))(""))
-    ((("x" "4"))(""))
-    ((("b" "4"))(""))
+    ;((("x" "4"))(""))
+    ;((("b" "4"))(""))
     ((("m" "4"))(""))
     ((("w" "4"))(""))
-    ((("v" "4"))(""))
-    ((("z" "4"))(""))
+    ;((("v" "4"))(""))
+    ;((("z" "4"))(""))
     ((("/" "4"))("")) 
-    ((("1" "5"))(""))
-    ((("2" "5"))(""))
-    ((("3" "5"))(""))
-    ((("4" "5"))(""))
-    ((("5" "5"))(""))
-    ((("6" "5"))(""))
-    ((("7" "5"))(""))
-    ((("8" "5"))(""))
-    ((("9" "5"))(""))
-    ((("0" "5"))(""))
+    ;((("1" "5"))(""))
+    ;((("2" "5"))(""))
+    ;((("3" "5"))(""))
+    ;((("4" "5"))(""))
+    ;((("5" "5"))(""))
+    ;((("6" "5"))(""))
+    ;((("7" "5"))(""))
+    ;((("8" "5"))(""))
+    ;((("9" "5"))(""))
+    ;((("0" "5"))(""))
     ((("," "5"))(""))
     ((("." "5"))(""))
     ((("p" "5"))(""))
     ((("y" "5"))(""))
-    ((("f" "5"))(""))
-    ((("g" "5"))(""))
-    ((("c" "5"))(""))
+    ;((("f" "5"))(""))
+    ;((("g" "5"))(""))
+    ;((("c" "5"))(""))
     ((("r" "5"))(""))
     ((("l" "5"))(""))
-    ((("a" "5"))(""))
+    ;((("a" "5"))(""))
     ((("o" "5"))(""))
     ((("e" "5"))(""))
     ((("u" "5"))(""))
     ((("i" "5"))("̩"))
-    ((("d" "5"))(""))
+    ;((("d" "5"))(""))
     ((("h" "5"))(""))
-    ((("t" "5"))(""))
+    ;((("t" "5"))(""))
     ((("n" "5"))("¬"))
-    ((("s" "5"))(""))
+    ;((("s" "5"))(""))
     (((";" "5"))(""))
     ((("q" "5"))(""))
     ((("j" "5"))(""))
     ((("k" "5"))(""))
-    ((("x" "5"))(""))
-    ((("b" "5"))(""))
+    ;((("x" "5"))(""))
+    ;((("b" "5"))(""))
     ((("m" "5"))(""))
     ((("w" "5"))("˿"))
-    ((("v" "5"))(""))
-    ((("z" "5"))(""))
+    ;((("v" "5"))(""))
+    ;((("z" "5"))(""))
     ((("/" "5"))(""))
-    ((("1" "6"))(""))
-    ((("2" "6"))(""))
-    ((("3" "6"))(""))
-    ((("4" "6"))(""))
-    ((("5" "6"))(""))
-    ((("6" "6"))(""))
-    ((("7" "6"))(""))
-    ((("8" "6"))(""))
-    ((("9" "6"))(""))
-    ((("0" "6"))(""))
-    ((("," "6"))(""))
-    ((("." "6"))(""))
-    ((("p" "6"))(""))
-    ((("y" "6"))(""))
+    ;((("1" "6"))(""))
+    ;((("2" "6"))(""))
+    ;((("3" "6"))(""))
+    ;((("4" "6"))(""))
+    ;((("5" "6"))(""))
+    ;((("6" "6"))(""))
+    ;((("7" "6"))(""))
+    ;((("8" "6"))(""))
+    ;((("9" "6"))(""))
+    ;((("0" "6"))(""))
+    ;((("," "6"))(""))
+    ;((("." "6"))(""))
+    ;((("p" "6"))(""))
+    ;((("y" "6"))(""))
     ((("f" "6"))(""))
     ((("g" "6"))(""))
     ((("c" "6"))(""))
     ((("r" "6"))(""))
-    ((("l" "6"))(""))
+    ;((("l" "6"))(""))
     ((("a" "6"))(""))
-    ((("o" "6"))(""))
+    ;((("o" "6"))(""))
     ((("e" "6"))(""))
-    ((("u" "6"))(""))
-    ((("i" "6"))(""))
+    ;((("u" "6"))(""))
+    ;((("i" "6"))(""))
     ((("d" "6"))(""))
-    ((("h" "6"))(""))
+    ;((("h" "6"))(""))
     ((("t" "6"))(""))
-    ((("n" "6"))(""))
+    ;((("n" "6"))(""))
     ((("s" "6"))(""))
-    (((";" "6"))(""))
+    ;(((";" "6"))(""))
     ((("q" "6"))(""))
-    ((("j" "6"))(""))
-    ((("k" "6"))(""))
+    ;((("j" "6"))(""))
+    ;((("k" "6"))(""))
     ((("x" "6"))(""))
     ((("b" "6"))(""))
-    ((("m" "6"))(""))
+    ;((("m" "6"))(""))
     ((("w" "6"))(""))
     ((("v" "6"))(""))
     ((("z" "6"))(""))
-    ((("/" "6"))(""))
-    ((("1" "7"))(""))
-    ((("2" "7"))(""))
-    ((("3" "7"))(""))
-    ((("4" "7"))(""))
-    ((("5" "7"))(""))
-    ((("6" "7"))(""))
-    ((("7" "7"))(""))
-    ((("8" "7"))(""))
-    ((("9" "7"))(""))
-    ((("0" "7"))(""))
-    ((("," "7"))(""))
-    ((("." "7"))(""))
+    ;((("/" "6"))(""))
+    ;((("1" "7"))(""))
+    ;((("2" "7"))(""))
+    ;((("3" "7"))(""))
+    ;((("4" "7"))(""))
+    ;((("5" "7"))(""))
+    ;((("6" "7"))(""))
+    ;((("7" "7"))(""))
+    ;((("8" "7"))(""))
+    ;((("9" "7"))(""))
+    ;((("0" "7"))(""))
+    ;((("," "7"))(""))
+    ;((("." "7"))(""))
     ((("p" "7"))(""))
-    ((("y" "7"))(""))
+    ;((("y" "7"))(""))
     ((("f" "7"))(""))
     ((("g" "7"))("æ"))
     ((("c" "7"))(""))
@@ -300,149 +300,149 @@
     ((("d" "7"))(""))
     ((("h" "7"))(""))
     ((("t" "7"))(""))
-    ((("n" "7"))(""))
+    ;((("n" "7"))(""))
     ((("s" "7"))(""))
-    (((";" "7"))(""))
+    ;(((";" "7"))(""))
     ((("q" "7"))("ü"))
     ((("j" "7"))(""))
     ((("k" "7"))(""))
     ((("x" "7"))(""))
     ((("b" "7"))(""))
-    ((("m" "7"))(""))
+    ;((("m" "7"))(""))
     ((("w" "7"))(""))
     ((("v" "7"))(""))
     ((("z" "7"))(""))
-    ((("/" "7"))(""))
-    ((("1" "8"))(""))
-    ((("2" "8"))(""))
-    ((("3" "8"))(""))
-    ((("4" "8"))(""))
-    ((("5" "8"))(""))
-    ((("6" "8"))(""))
-    ((("7" "8"))(""))
-    ((("8" "8"))(""))
-    ((("9" "8"))(""))
-    ((("0" "8"))(""))
-    ((("," "8"))(""))
-    ((("." "8"))(""))
+    ;((("/" "7"))(""))
+    ;((("1" "8"))(""))
+    ;((("2" "8"))(""))
+    ;((("3" "8"))(""))
+    ;((("4" "8"))(""))
+    ;((("5" "8"))(""))
+    ;((("6" "8"))(""))
+    ;((("7" "8"))(""))
+    ;((("8" "8"))(""))
+    ;((("9" "8"))(""))
+    ;((("0" "8"))(""))
+    ;((("," "8"))(""))
+    ;((("." "8"))(""))
     ((("p" "8"))(""))
     ((("y" "8"))(""))
     ((("f" "8"))(""))
     ((("g" "8"))("˽"))
     ((("c" "8"))(""))
     ((("r" "8"))(""))
-    ((("l" "8"))(""))
+    ;((("l" "8"))(""))
     ((("a" "8"))(""))
     ((("o" "8"))(""))
     ((("e" "8"))(""))
     ((("u" "8"))(""))
     ((("i" "8"))(""))
     ((("d" "8"))(""))
-    ((("h" "8"))(""))
+    ;((("h" "8"))(""))
     ((("t" "8"))(""))
-    ((("n" "8"))(""))
+    ;((("n" "8"))(""))
     ((("s" "8"))(""))
-    (((";" "8"))(""))
+    ;(((";" "8"))(""))
     ((("q" "8"))(""))
-    ((("j" "8"))(""))
-    ((("k" "8"))(""))
+    ;((("j" "8"))(""))
+    ;((("k" "8"))(""))
     ((("x" "8"))(""))
     ((("b" "8"))("ʻ"))
-    ((("m" "8"))(""))
+    ;((("m" "8"))(""))
     ((("w" "8"))(""))
     ((("v" "8"))("ε"))
     ((("z" "8"))(""))
-    ((("/" "8"))(""))
-    ((("1" "9"))(""))
-    ((("2" "9"))(""))
-    ((("3" "9"))(""))
-    ((("4" "9"))(""))
-    ((("5" "9"))(""))
-    ((("6" "9"))(""))
-    ((("7" "9"))(""))
-    ((("8" "9"))(""))
-    ((("9" "9"))(""))
-    ((("0" "9"))(""))
-    ((("," "9"))(""))
-    ((("." "9"))(""))
+    ;((("/" "8"))(""))
+    ;((("1" "9"))(""))
+    ;((("2" "9"))(""))
+    ;((("3" "9"))(""))
+    ;((("4" "9"))(""))
+    ;((("5" "9"))(""))
+    ;((("6" "9"))(""))
+    ;((("7" "9"))(""))
+    ;((("8" "9"))(""))
+    ;((("9" "9"))(""))
+    ;((("0" "9"))(""))
+    ;((("," "9"))(""))
+    ;((("." "9"))(""))
     ((("p" "9"))("Ģ"))
-    ((("y" "9"))(""))
+    ;((("y" "9"))(""))
     ((("f" "9"))(""))
     ((("g" "9"))(""))
     ((("c" "9"))(""))
     ((("r" "9"))(""))
-    ((("l" "9"))(""))
+    ;((("l" "9"))(""))
     ((("a" "9"))(""))
     ((("o" "9"))(""))
     ((("e" "9"))(""))
     ((("u" "9"))("ǵ"))
     ((("i" "9"))("ǡ"))
     ((("d" "9"))(""))
-    ((("h" "9"))(""))
+    ;((("h" "9"))(""))
     ((("t" "9"))(""))
-    ((("n" "9"))(""))
+    ;((("n" "9"))(""))
     ((("s" "9"))(""))
-    (((";" "9"))(""))
+    ;(((";" "9"))(""))
     ((("q" "9"))(""))
-    ((("j" "9"))(""))
-    ((("k" "9"))(""))
+    ;((("j" "9"))(""))
+    ;((("k" "9"))(""))
     ((("x" "9"))(""))
     ((("b" "9"))(""))
-    ((("m" "9"))(""))
+    ;((("m" "9"))(""))
     ((("w" "9"))(""))
     ((("v" "9"))("ð"))
     ((("z" "9"))(""))
-    ((("/" "9"))(""))
-    ((("1" "0"))(""))
-    ((("2" "0"))(""))
-    ((("3" "0"))(""))
-    ((("4" "0"))(""))
-    ((("5" "0"))(""))
-    ((("6" "0"))(""))
-    ((("7" "0"))(""))
-    ((("8" "0"))(""))
-    ((("9" "0"))(""))
-    ((("0" "0"))(""))
-    ((("," "0"))(""))
-    ((("." "0"))(""))
+    ;((("/" "9"))(""))
+    ;((("1" "0"))(""))
+    ;((("2" "0"))(""))
+    ;((("3" "0"))(""))
+    ;((("4" "0"))(""))
+    ;((("5" "0"))(""))
+    ;((("6" "0"))(""))
+    ;((("7" "0"))(""))
+    ;((("8" "0"))(""))
+    ;((("9" "0"))(""))
+    ;((("0" "0"))(""))
+    ;((("," "0"))(""))
+    ;((("." "0"))(""))
     ((("p" "0"))(""))
     ((("y" "0"))(""))
     ((("f" "0"))(""))
     ((("g" "0"))(""))
     ((("c" "0"))(""))
     ((("r" "0"))(""))
-    ((("l" "0"))(""))
+    ;((("l" "0"))(""))
     ((("a" "0"))("§"))
     ((("o" "0"))("θ"))
     ((("e" "0"))("ɼ"))
     ((("u" "0"))("ζ"))
     ((("i" "0"))("ά"))
     ((("d" "0"))(""))
-    ((("h" "0"))(""))
+    ;((("h" "0"))(""))
     ((("t" "0"))(""))
-    ((("n" "0"))(""))
+    ;((("n" "0"))(""))
     ((("s" "0"))("¸"))
-    (((";" "0"))(""))
+    ;(((";" "0"))(""))
     ((("q" "0"))(""))
-    ((("j" "0"))(""))
-    ((("k" "0"))(""))
+    ;((("j" "0"))(""))
+    ;((("k" "0"))(""))
     ((("x" "0"))(""))
     ((("b" "0"))(""))
-    ((("m" "0"))(""))
+    ;((("m" "0"))(""))
     ((("w" "0"))(""))
     ((("v" "0"))(""))
     ((("z" "0"))(""))
-    ((("/" "0"))(""))
+    ;((("/" "0"))(""))
     ((("1" ","))("α"))
     ((("2" ","))(""))
     ((("3" ","))(""))
     ((("4" ","))("Ʀ"))
     ((("5" ","))(""))
-    ((("6" ","))(""))
-    ((("7" ","))(""))
-    ((("8" ","))(""))
-    ((("9" ","))(""))
-    ((("0" ","))(""))
+    ;((("6" ","))(""))
+    ;((("7" ","))(""))
+    ;((("8" ","))(""))
+    ;((("9" ","))(""))
+    ;((("0" ","))(""))
     ((("," ","))(""))
     ((("." ","))(""))
     ((("p" ","))(""))
@@ -478,11 +478,11 @@
     ((("3" "."))("?"))
     ((("4" "."))(""))
     ((("5" "."))(""))
-    ((("6" "."))(""))
-    ((("7" "."))(""))
-    ((("8" "."))(""))
-    ((("9" "."))(""))
-    ((("0" "."))(""))
+    ;((("6" "."))(""))
+    ;((("7" "."))(""))
+    ;((("8" "."))(""))
+    ;((("9" "."))(""))
+    ;((("0" "."))(""))
     ((("," "."))(""))
     ((("." "."))(""))
     ((("p" "."))(""))
@@ -518,11 +518,11 @@
     ((("3" "p"))(""))
     ((("4" "p"))(""))
     ((("5" "p"))(""))
-    ((("6" "p"))(""))
-    ((("7" "p"))(""))
+    ;((("6" "p"))(""))
+    ;((("7" "p"))(""))
     ((("8" "p"))(""))
     ((("9" "p"))(""))
-    ((("0" "p"))(""))
+    ;((("0" "p"))(""))
     ((("," "p"))(""))
     ((("." "p"))(""))
     ((("p" "p"))(""))
@@ -558,7 +558,7 @@
     ((("3" "y"))(""))
     ((("4" "y"))(""))
     ((("5" "y"))(""))
-    ((("6" "y"))(""))
+    ;((("6" "y"))(""))
     ((("7" "y"))(""))
     ((("8" "y"))(""))
     ((("9" "y"))(""))
@@ -674,10 +674,10 @@
     ((("z" "g"))("ž"))
     ((("/" "g"))(""))
     ((("1" "c"))(""))
-    ((("2" "c"))(""))
-    ((("3" "c"))(""))
-    ((("4" "c"))(""))
-    ((("5" "c"))(""))
+    ;((("2" "c"))(""))
+    ;((("3" "c"))(""))
+    ;((("4" "c"))(""))
+    ;((("5" "c"))(""))
     ((("6" "c"))("˼"))
     ((("7" "c"))(""))
     ((("8" "c"))(""))
@@ -758,9 +758,9 @@
     ((("3" "l"))("̴"))
     ((("4" "l"))(""))
     ((("5" "l"))(""))
-    ((("6" "l"))(""))
+    ;((("6" "l"))(""))
     ((("7" "l"))(""))
-    ((("8" "l"))(""))
+    ;((("8" "l"))(""))
     ((("9" "l"))(""))
     ((("0" "l"))(""))
     ((("," "l"))(""))
@@ -838,7 +838,7 @@
     ((("3" "o"))(""))
     ((("4" "o"))("ƨ"))
     ((("5" "o"))(""))
-    ((("6" "o"))(""))
+    ;((("6" "o"))(""))
     ((("7" "o"))(""))
     ((("8" "o"))(""))
     ((("9" "o"))(""))
@@ -918,7 +918,7 @@
     ((("3" "u"))(""))
     ((("4" "u"))(""))
     ((("5" "u"))("ʣ"))
-    ((("6" "u"))(""))
+    ;((("6" "u"))(""))
     ((("7" "u"))(""))
     ((("8" "u"))(""))
     ((("9" "u"))(""))
@@ -958,7 +958,7 @@
     ((("3" "i"))(""))
     ((("4" "i"))("ɮ"))
     ((("5" "i"))("Τ"))
-    ((("6" "i"))(""))
+    ;((("6" "i"))(""))
     ((("7" "i"))(""))
     ((("8" "i"))(""))
     ((("9" "i"))(""))
@@ -1038,7 +1038,7 @@
     ((("3" "h"))(""))
     ((("4" "h"))(""))
     ((("5" "h"))(""))
-    ((("6" "h"))(""))
+    ;((("6" "h"))(""))
     ((("7" "h"))(""))
     ((("8" "h"))(""))
     ((("9" "h"))(""))
@@ -1118,11 +1118,11 @@
     ((("3" "n"))(""))
     ((("4" "n"))(""))
     ((("5" "n"))("ϯ"))
-    ((("6" "n"))(""))
-    ((("7" "n"))(""))
-    ((("8" "n"))(""))
-    ((("9" "n"))(""))
-    ((("0" "n"))(""))
+    ;((("6" "n"))(""))
+    ;((("7" "n"))(""))
+    ;((("8" "n"))(""))
+    ;((("9" "n"))(""))
+    ;((("0" "n"))(""))
     ((("," "n"))(""))
     ((("." "n"))(""))
     ((("p" "n"))(""))
@@ -1198,11 +1198,11 @@
     ((("3" ";"))(""))
     ((("4" ";"))(""))
     ((("5" ";"))(""))
-    ((("6" ";"))(""))
+    ;((("6" ";"))(""))
     ((("7" ";"))(""))
     ((("8" ";"))("Ʒ"))
     ((("9" ";"))("ƫ"))
-    ((("0" ";"))(""))
+    ;((("0" ";"))(""))
     ((("," ";"))(""))
     ((("." ";"))(""))
     ((("p" ";"))(""))
@@ -1278,7 +1278,7 @@
     ((("3" "j"))(""))
     ((("4" "j"))(""))
     ((("5" "j"))(""))
-    ((("6" "j"))(""))
+    ;((("6" "j"))(""))
     ((("7" "j"))(""))
     ((("8" "j"))(""))
     ((("9" "j"))("ź"))
@@ -1318,7 +1318,7 @@
     ((("3" "k"))(""))
     ((("4" "k"))(""))
     ((("5" "k"))(""))
-    ((("6" "k"))(""))
+    ;((("6" "k"))(""))
     ((("7" "k"))(""))
     ((("8" "k"))(""))
     ((("9" "k"))("Ű"))
@@ -1354,10 +1354,10 @@
     ((("z" "k"))(""))
     ((("/" "k"))(""))
     ((("1" "x"))(""))
-    ((("2" "x"))(""))
-    ((("3" "x"))(""))
-    ((("4" "x"))(""))
-    ((("5" "x"))(""))
+    ;((("2" "x"))(""))
+    ;((("3" "x"))(""))
+    ;((("4" "x"))(""))
+    ;((("5" "x"))(""))
     ((("6" "x"))(""))
     ((("7" "x"))(""))
     ((("8" "x"))(""))
@@ -1394,10 +1394,10 @@
     ((("z" "x"))("Ƚ"))
     ((("/" "x"))(""))
     ((("1" "b"))(""))
-    ((("2" "b"))(""))
-    ((("3" "b"))(""))
-    ((("4" "b"))(""))
-    ((("5" "b"))(""))
+    ;((("2" "b"))(""))
+    ;((("3" "b"))(""))
+    ;((("4" "b"))(""))
+    ;((("5" "b"))(""))
     ((("6" "b"))(""))
     ((("7" "b"))(""))
     ((("8" "b"))(""))
@@ -1438,11 +1438,11 @@
     ((("3" "m"))(""))
     ((("4" "m"))("Ǿ"))
     ((("5" "m"))("Ϸ"))
-    ((("6" "m"))(""))
-    ((("7" "m"))(""))
-    ((("8" "m"))(""))
-    ((("9" "m"))(""))
-    ((("0" "m"))(""))
+    ;((("6" "m"))(""))
+    ;((("7" "m"))(""))
+    ;((("8" "m"))(""))
+    ;((("9" "m"))(""))
+    ;((("0" "m"))(""))
     ((("," "m"))(""))
     ((("." "m"))(""))
     ((("p" "m"))(""))
@@ -1514,10 +1514,10 @@
     ((("z" "w"))(""))
     ((("/" "w"))(""))
     ((("1" "v"))(""))
-    ((("2" "v"))(""))
-    ((("3" "v"))(""))
-    ((("4" "v"))(""))
-    ((("5" "v"))(""))
+    ;((("2" "v"))(""))
+    ;((("3" "v"))(""))
+    ;((("4" "v"))(""))
+    ;((("5" "v"))(""))
     ((("6" "v"))(""))
     ((("7" "v"))(""))
     ((("8" "v"))(""))
@@ -1554,10 +1554,10 @@
     ((("z" "v"))(""))
     ((("/" "v"))(""))
     ((("1" "z"))(""))
-    ((("2" "z"))(""))
+    ;((("2" "z"))(""))
     ((("3" "z"))(""))
-    ((("4" "z"))(""))
-    ((("5" "z"))(""))
+    ;((("4" "z"))(""))
+    ;((("5" "z"))(""))
     ((("6" "z"))(""))
     ((("7" "z"))(""))
     ((("8" "z"))(""))
@@ -1598,11 +1598,11 @@
     ((("3" "/"))(""))
     ((("4" "/"))("Ȣ"))
     ((("5" "/"))(""))
-    ((("6" "/"))(""))
-    ((("7" "/"))(""))
-    ((("8" "/"))(""))
-    ((("9" "/"))(""))
-    ((("0" "/"))(""))
+    ;((("6" "/"))(""))
+    ;((("7" "/"))(""))
+    ;((("8" "/"))(""))
+    ;((("9" "/"))(""))
+    ;((("0" "/"))(""))
     ((("," "/"))(""))
     ((("." "/"))("ȿ"))
     ((("p" "/"))(""))
